@@ -7,7 +7,10 @@
  */
 
 #include <stdio.h>
-#include "nqconf.h"
+
+#include "config.h"
+
+#include "modemconfig.h"
 
 #define asmline(s)		puts("\"" s ";\\n\\t\"")
 #define asmline2(s1,d,s2)	printf("\"%s%d%s;\\n\\t\"\n", s1, d, s2)
